unit EditProject;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms, UITypes,
  Dialogs, StdCtrls, DB, ADODB, ExtCtrls;

type
  TFormEditProject = class(TForm)
    GroupBox1: TGroupBox;
    ButtonClose: TButton;
    ButtonApply: TButton;
    LabelName: TLabel;
    LabelTableName: TLabel;
    LabelRegSeed: TLabel;
    EditName: TEdit;
    EditTableName: TEdit;
    EditRegSeed: TEdit;
    ADOConnection: TADOConnection;
    ADOQuery: TADOQuery;
    OpenDialog: TOpenDialog;
    ImageIcon: TImage;
    EditIconFileName: TEdit;
    ButtonSelectIcon: TButton;
    CheckBoxChangeIcon: TCheckBox;
    DataSource: TDataSource;
    Label1: TLabel;
    EditDownloadURL: TEdit;
    procedure ButtonApplyClick(Sender: TObject);
    procedure ButtonCloseClick(Sender: TObject);
    procedure EditNameChange(Sender: TObject);
    procedure ButtonSelectIconClick(Sender: TObject);
    procedure CheckBoxChangeIconClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
    PreviousProjectTableName: String;
    ProjectID: Integer;
    procedure SQLEditProject(ProjectID: Integer; ProjectName: String; OldTableName, NewTableName, RegSeed: String; IconFileName: String; DownloadURL: String);
    procedure ClearIcon;
    procedure LoadData;
  end;

var
  FormEditProject: TFormEditProject;

implementation

Uses
    Main,
    Settings,
    StrUtils,
    Helper3delite;

{$R *.dfm}

procedure TFormEditProject.ButtonApplyClick(Sender: TObject);
begin
    Screen.Cursor := crAppStart;
    try
        if CheckBoxChangeIcon.Checked then begin
            SQLEditProject(ProjectID, EditName.Text, PreviousProjectTableName, EditTableName.Text, EditRegSeed.Text, EditIconFileName.Text, EditDownloadURL.Text);
        end else begin
            SQLEditProject(ProjectID, EditName.Text, PreviousProjectTableName, EditTableName.Text, EditRegSeed.Text, '', EditDownloadURL.Text);
        end;
        Screen.Cursor := crDefault;
        MessageDlg('Successfully changed project "' + EditName.Text + '".', mtConfirmation, [mbOk], 0);
    except
        on E: Exception do begin
            Screen.Cursor := crDefault;
            MessageDlg('Error: ' + E.Message, mtError, [mbOk], 0);
        end;
    end;
end;

procedure TFormEditProject.ButtonCloseClick(Sender: TObject);
begin
    Close;
end;

procedure TFormEditProject.ButtonSelectIconClick(Sender: TObject);
begin
    if OpenDialog.Execute then begin
        EditIconFileName.Text := OpenDialog.FileName;
        ImageIcon.Picture.LoadFromFile(EditIconFileName.Text);
    end;
end;

procedure TFormEditProject.EditNameChange(Sender: TObject);
begin
    EditTableName.Text := StrConvertToSQLName(EditName.Text);
end;

procedure TFormEditProject.SQLEditProject(ProjectID: Integer; ProjectName: String; OldTableName, NewTableName, RegSeed: String; IconFileName: String; DownloadURL: String);
begin

    ADOConnection.Close;

    ADOConnection.ConnectionString := FormSettings.EditMySQLConnectionString.Text;

    ADOQuery.SQL.Clear;

    //* Set to use our new database (specified by name)
    ADOQuery.SQL.Add('USE ' + FormSettings.EditDatabaseNameToUse.Text + ';');

    //* Insert a new record

    if FileExists(IconFileName) then begin
        ADOQuery.SQL.Add('UPDATE ' + TN_PROJECTS);
        ADOQuery.SQL.Add('SET ' + CN_PROJECTNAME + ' = :a,');
        ADOQuery.SQL.Add(CN_PROJECT_TABLENAME + ' = :b,');
        ADOQuery.SQL.Add(CN_PROJECT_REG_SEED + ' = :c,');
        ADOQuery.SQL.Add(CN_PROJECT_ICON + ' = :d,');
        ADOQuery.SQL.Add(CN_PROJECT_DOWNLOAD_URL + ' = :e');
        ADOQuery.SQL.Add('WHERE ' + CN_PROJECT_ID + ' = ' + IntToStr(ProjectID));
        ADOQuery.Parameters.ParamByName('a').DataType := ftWideString;
        ADOQuery.Parameters.ParamByName('a').Value := ProjectName;
        ADOQuery.Parameters.ParamByName('b').DataType := ftString;
        ADOQuery.Parameters.ParamByName('b').Value := NewTableName;
        ADOQuery.Parameters.ParamByName('c').DataType := ftString;
        ADOQuery.Parameters.ParamByName('c').Value := RegSeed;
        ADOQuery.Parameters.ParamByName('d').DataType := ftVarBytes;
        ADOQuery.Parameters.ParamByName('d').LoadFromFile(IconFileName, ftVarBytes);
        ADOQuery.Parameters.ParamByName('e').DataType := ftWideString;
        ADOQuery.Parameters.ParamByName('e').Value := DownloadURL;
    end else begin
        ADOQuery.SQL.Add('UPDATE ' + TN_PROJECTS);
        ADOQuery.SQL.Add('SET ' + CN_PROJECTNAME + ' = :a,');
        ADOQuery.SQL.Add(CN_PROJECT_TABLENAME + ' = :b,');
        ADOQuery.SQL.Add(CN_PROJECT_REG_SEED + ' = :c,');
        //ADOQuery.SQL.Add(CN_PROJECT_ICON + ' = :d,');
        ADOQuery.SQL.Add(CN_PROJECT_DOWNLOAD_URL + ' = :e');
        ADOQuery.SQL.Add('WHERE ' + CN_PROJECT_ID + ' = ' + IntToStr(ProjectID));
        ADOQuery.Parameters.ParamByName('a').DataType := ftWideString;
        ADOQuery.Parameters.ParamByName('a').Value := ProjectName;
        ADOQuery.Parameters.ParamByName('b').DataType := ftString;
        ADOQuery.Parameters.ParamByName('b').Value := NewTableName;
        ADOQuery.Parameters.ParamByName('c').DataType := ftString;
        ADOQuery.Parameters.ParamByName('c').Value := RegSeed;
        //ADOQuery.Parameters.ParamByName('d').DataType := ftVarBytes;
        //ADOQuery.Parameters.ParamByName('d').LoadFromFile(IconFileName, ftVarBytes);
        ADOQuery.Parameters.ParamByName('e').DataType := ftWideString;
        ADOQuery.Parameters.ParamByName('e').Value := DownloadURL;
    end;

    ADOQuery.ExecSql;

    ADOQuery.SQL.Clear;

    //* Set to use our new database (specified by name)
    ADOQuery.SQL.Add('USE ' + FormSettings.EditDatabaseNameToUse.Text + ';');
    //* Create a new table
    //ADOQuery.SQL.Add('RENAME TABLE ''' + OldTableName + ''' TO ''' + NewTableName + ''';');
    //ADOQuery.SQL.Add('ALTER TABLE ''' + OldTableName + ''' RENAME ''' + NewTableName + '''');
    ADOQuery.SQL.Add('EXEC SP_RENAME ''' + OldTableName + ''', ''' + NewTableName + '''');

    ADOQuery.ExecSql;

    ADOConnection.Close;

end;

procedure TFormEditProject.CheckBoxChangeIconClick(Sender: TObject);
begin
    EditIconFileName.Enabled := CheckBoxChangeIcon.Checked;
    ButtonSelectIcon.Enabled := CheckBoxChangeIcon.Checked;
end;

procedure TFormEditProject.ClearIcon;
begin
    ImageIcon.Picture.Assign(nil);
    EditIconFileName.Text := 'Select an icon file...';
    CheckBoxChangeIcon.Checked := False;
end;

procedure TFormEditProject.LoadData;
var
    Icon: TIcon;
    IconBytes: TBytes;
    IconStream: TMemoryStream;
begin

    ClearIcon;

    ADOConnection.Close;

    ADOConnection.ConnectionString := FormSettings.EditMySQLConnectionString.Text;

    ADOQuery.Close;
    ADOQuery.SQL.Clear;

    //* Set to use our new database (specified by name)
    ADOQuery.SQL.Add('USE ' + FormSettings.EditDatabaseNameToUse.Text + ';');
    //* Get all data
    ADOQuery.SQL.Add('SELECT * FROM ' + TN_PROJECTS + ' WHERE ' + CN_PROJECT_ID + ' = ' + IntToStr(ProjectID));
    ADOQuery.Open;

    DataSource.DataSet.First;
    while NOT DataSource.DataSet.Eof do begin
        EditName.Text := DataSource.DataSet.FieldByName(CN_PROJECTNAME).AsWideString;
        //SubItems.Add(DataSource.DataSet.FieldByName(RN_PROJECT_ID).AsWideString);
        EditTableName.Text := DataSource.DataSet.FieldByName(CN_PROJECT_TABLENAME).AsString;
        EditRegSeed.Text := DataSource.DataSet.FieldByName(CN_PROJECT_REG_SEED).AsString;
        IconBytes := DataSource.DataSet.FieldByName(CN_PROJECT_ICON).AsBytes;
        if Length(IconBytes) > 0 then begin
            Icon := TIcon.Create;
            IconStream := TMemoryStream.Create;
            IconStream.Write(Pointer(IconBytes)^, Length(IconBytes));
            IconStream.Seek(0, soBeginning);
            Icon.LoadFromStream(IconStream);
            ImageIcon.Picture.Assign(Icon);
            FreeAndNil(IconStream);
            FreeAndNil(Icon);
        end else begin
            ImageIcon.Picture.Assign(nil);
        end;
        EditDownloadURL.Text := DataSource.DataSet.FieldByName(CN_PROJECT_DOWNLOAD_URL).AsWideString;
        DataSource.DataSet.Next;
    end;

    ADOQuery.Close;

    ADOConnection.Close;
end;

end.
